%This mfile was created in Matlab R2010b.  Results were published in the
%following paper (Mackey and Lamb, 2013).  Please cite the following paper should these codes be
%used for a publication.

%Mackey, B.H., and Lamb, M.P., 2013, 
%Deciphering boulder mobility and erosion from cosmogenic nuclide exposure dating: 
%Journal of Geophysical Research: Earth Surface,doi: 10.1002/jgrf.20035

%Disclaimer:  These codes have only been tested for the conditions published
%in the manuscript. Numerical errors are likely outside of these bounds given
%the crude iteration schemes used.  Use at your own risk.

%Copyright (C) 2013 Michael Lamb <mpl@gps.caltech.edu>

% This program is free software: you can redistribute it and/or modify it 
% under the terms of the GNU General Public License as published by the 
% Free Software Foundation. You should have received a copy of the GNU 
% General Public License along with this program.  If not, see 
% http://www.gnu.org/licenses.

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


% Shows the evolution of nuclides around and eroding and mobile boulder,
% per fig 5 of Mackey and Lamb (2013)
% 
% Change the variables below for different scenarios

%can take a while with large boulders or long ttimes. May need to chance
%axis limits with different sized boudlers

%multcirc_fixtime.m models the accumulation of cosmogenic nuclides in a 1-D
%circle. The boulder is allowed to erode, and regularlay roll through a
%random angle

%Inputs
%rho is the length of the radius of the boulder in mm
%rolls is number of times boulder rolls over
%Er is the erosion rate in mm/yr eg 0.1 is 0.1 mm/yr
%rayz is the number of cosmic rays to target each node per sitting interval
%ttime is the total time for the boulder to erode

rho = 10000;
rolls = 10;
Er = 0.05;
ttime = 100000;

tic

%Model setup

spokes = 25;%number of spokes in the boulder model

eros_dist = Er*ttime; %length of eroded radius during erosion run - conc nodes in this section
%>>> Ensure this is less than radius

shed_thick = 25; %nominal thickness to remove each interation (mm)

nodes = 1+(round((eros_dist/rolls)./shed_thick))*rolls ; % number of nodes (shells) of the original boulder. Calculated to be one shell every 25mm

%First set up the boulder framwork with a polar matrix
r = linspace(rho-eros_dist,rho,nodes); %the spoke separated into evenly separated increments (number of nodes) over the eroded interval
zeta = linspace(2*pi/spokes/2,2*pi-(2*pi/spokes/2),spokes)'; %Angular interval
Xcol = []; %big column of all x values
Ycol = []; %big column lf all y values
Rcol = [];
m = 1; %increment

efold = 0.83; %efolding length (m)

rho1=rho; %record of original radius


for m = 1:nodes; %make shells - shell number = nodes
    [X,Y]=pol2cart(zeta,r(m)); %Cartesian coordinates of each concentric shell
    Xcol = [Xcol;X];
    Ycol = [Ycol;Y];
end

for m=1:spokes; % Record of the radius at each point.
    Rcol = [Rcol;r];
end
Rcol = Rcol(:); %Rcol is same length as Xcol and Ycol

Lx = length(Xcol);
y_alt(1:Lx)=0; %MOD - makes it a 2-D disc

n = 1;
DataC = []; %Empty matrix into which all the concs for each step are stored
rotations = [];
time = [];
diam = [];
f=1;
outsurf = []; %matrix of the exposure of outer shell each time step
skin = []; %exposure each time step used to accumulate outsurf
cumage = [0];

stable = 1;
years = ttime/rolls; %time at each orientation
eros_years = years*Er; %Total thickness of boulder removed during each sitting interval (mm)
steps50mm = round(eros_years/shed_thick); %number of iterations to do at each time step if amount eroded is > 50mm.

time50mm = years/steps50mm; %time to hold before removing a ~50mm shell.

rotate = zeros(1,steps50mm); %rotation vector if need to hold boulder several steps before rotating


for f = 1:rolls, %Start big loop - 1 loop per step / rolling event
    
    rotate(steps50mm) = 2*pi*rand(1); %make boulder rotate at end of sitting interval
    for stable = 1:steps50mm; %removes incremental shells while boulder is stable
        
     
    omega = rotate(stable); %random angle (rad) for boulder to roll in clockwise direction - will be zero until stable = steps50mm
    drho = Er*time50mm; %amount to erode the boulder for the given interval based on prescribed erosion rate (Er)
    accum = [];
    
     i1 = find(Rcol<=rho);
    [accum1] = sphere_line3_Lal(Xcol(i1)./1000, y_alt(i1)./1000, Ycol(i1)./1000, rho./1000); %this function assumes meters
    accum1 = (accum1.*0.5252.*time50mm); %conversion for normalization by flat surface (1 atom/g/yr), multiply by years of exposure
    accum(1:Lx)=NaN;
    accum(i1)=accum1;
    accum = accum';
    
    [DataC] = [DataC,accum]; %Builds matrix of conc at each point for each interval (Lx x (f x steps50mm))
        

    rho = rho-drho %erodes a bit off based on standardised erosion rate and sitting time
    
    XY=[Xcol,Ycol]; %Matrix of X and Y coordinates
    RotM = [cos(omega)  -sin(omega) ; sin(omega)  cos(omega)]; %Rotation matrix (clockwise)

    XrYr = XY*RotM; %rotates the points by angle omega (radians)

    Xcol = XrYr(:,1); %rotated x and y individual columns
    Ycol = XrYr(:,2);
    

  
    cumage = [cumage;cumage(end)+time50mm]; %Records the cumulative age at each step
    
    %find the outermost shell
    shellnorm =(rho-(rho1-eros_dist))/eros_dist*nodes;
    rhoint = fix(shellnorm); %outermost shell to nearest lower integer
    DataCstart = ((rhoint*spokes)+1); %Where to start in DataC
    DataCend = DataCstart+spokes-1; %where to end in DataC
    skin = DataC(DataCstart:DataCend,1:end); %Picks out the values in DataC reflecting external shell (spokes x f)
    
    skinsum=sum(skin,2);% (spokes x 1) - conc of the outer skin
    outsurf = [outsurf,skinsum]; %makes a matrix of skin concs at each rotation (spokes x f)
    skin = [];%empties skin for next iteration
    rotations = [rotations;omega]; %records rotation angle, 
    time = [time;years]; %records time of each step (cf. cumage)
    diam = [diam;rho]; %records diameter at each step
    
    
f;

    end %end stable erosion sequence
end %end big loop - ie, end of a rotation interval.



%     
ConcT = sum(DataC,2); %sum the concentration for each coordinate for all the exposure intervals (Lx x 1), and normalize by rayz

skinvar = std(outsurf)'; %variance and mean of the outer layer at each step
skinmean = mean(outsurf)';
skiniqr = iqr(outsurf)';
skinmax = max(outsurf)';
skinmin = min(outsurf)';
skinvarmean = (skinvar./skinmean);

DataC; % option on screen read out of conc data at each time step
age = sum(time); %total age of boulder at end of run
cumage = cumage(2:end);

concnorm = (skinmean*Er)/(efold*1000); %nondimensionalised concentration, C*
timenorm = (cumage*Er)/(efold*1000); %nondimensionalised time, T*
normrad=diam/rho1; %normalised radius

[shield] = [Xcol,Ycol,ConcT]; %resultant matrix
[stats_all] =[cumage,diam,skinmean,skinvar,skinvarmean,normrad,concnorm,timenorm,skinmax,skinmin,skiniqr,rotations]; %8 columns of data - this used in MC script


[stats]=[stats_all(steps50mm:steps50mm:end,:)]; %pulls out the data from the end of each sitting period, cf each shell shedding

toc

save boulder_5mrad_evolution_randroll

figure1 = figure;
axes1 = axes('Parent',figure1,'YTick',[0:2000:20000],'YColor',[0 0 0]);
box(axes1,'on');
hold(axes1,'all');
plot1 = plot(stats_all(:,1),stats_all(:,3),'Parent',axes1,'Color',[1 0 0],'linewidth', 1.5);
plot(stats_all(:,1),stats_all(:,3)+stats_all(:,4),'r-')
plot(stats_all(:,1),stats_all(:,3)-stats_all(:,4),'r-')
xlabel('Time (years)')
ylabel('Mean surface concentration (atoms/node)')
axes2 = axes('Parent',figure1,'YTick',[0:1000:5000]*0.001,'XTick',[],'YAxisLocation','right',...
    'YColor',[0 0 0],...
    'ColorOrder',[0 0.5 0;1 0 0;0 0.75 0.75;0.75 0 0.75;0.75 0.75 0;0.25 0.25 0.25;0 0 1],...
    'Color','none');
hold(axes2,'all');
 % Create plot
xlim(axes2,[0 ttime]); %change this to fit given input parameters
box(axes1,'off');
plot(stats_all(:,1),stats_all(:,2).*0.001, 'k-', 'Parent',axes2);
ylabel('Boulder radius (m)')

figure2 = figure;
axes3 = axes('Parent',figure2,'YTick',[0:0.1:1],'YColor',[0 0 0]);
box(axes3,'on');
hold(axes3,'all');
plot3 = plot(stats_all(:,1),stats_all(:,5),'Parent',axes3,'Color',[1 0 0]);
plot(stats(:,1),stats(:,5),'bo')
xlabel('Time (years)')
ylabel('Normalized variance (C_N)')
axes4 = axes('Parent',figure2,'YTick',[0:pi/4:2*pi]./pi,'XTick',[],'YAxisLocation','right',...
    'YColor',[0 0 0],...
      'ColorOrder',[0 0.5 0;1 0 0;0 0.75 0.75;0.75 0 0.75;0.75 0.75 0;0.25 0.25 0.25;0 0 1],...
    'Color','none');
hold(axes4,'all');
xlim(axes4,[0 ttime]);
ylim(axes4, [0 2]);
box(axes3,'off');
plot(stats(:,1),stats(:,12)./pi,'r*')
ylabel('Boulder rotation (pi)')
save boulder_5mrad_evolution


