
%This mfile was created in Matlab R2010b.  Results were published in the
%following paper (Mackey and Lamb, 2013).  Please cite the following paper should these codes be
%used for a publication.

%Mackey, B.H., and Lamb, M.P., 2013, 
%Deciphering boulder mobility and erosion from cosmogenic nuclide exposure dating: 
%Journal of Geophysical Research: Earth Surface,doi: 10.1002/jgrf.20035

%Disclaimer:  These codes have only been tested for the conditions published
%in the manuscript. Numerical errors are likely outside of these bounds given
%the crude iteration schemes used.  Use at your own risk.

%Copyright (C) 2013 Michael Lamb <mpl@gps.caltech.edu>

% This program is free software: you can redistribute it and/or modify it 
% under the terms of the GNU General Public License as published by the 
% Free Software Foundation. You should have received a copy of the GNU 
% General Public License along with this program.  If not, see 
% http://www.gnu.org/licenses.

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function [stats_all,stats,ConcT]= boulder_erode_lalMc_stable_noeros(rho,rolls,Er,ttime)

%this one is for no erosion - can rotate though.

%Inputs
%rho is the length of the radius of the boulder in mm
%rolls is number of times boulder rolls over
%Er is the erosion rate in mm/yr eg 0.1 is 0.1 mm/yr
%rayz is the number of cosmic rays to target each node per sitting interval
%ttime is the total time for the boulder to erode

tic

%Model setup
nodes = 1; %eros_dist/25; %50;% number of nodes (shells) of the original boulder. Calculated to be one shell at least every 25mm
spokes = 200;%number of spokes in the boulder model



%First set up the boulder framwork with a polar matrix
r = rho; %linspace(rho-eros_dist,rho-0.0001,nodes); %the spoke separated into evenly separated increments (number of nodes) over the eroded interval
zeta = linspace(2*pi/spokes/2,2*pi-(2*pi/spokes/2),spokes)'; %Angular interval
Xcol = []; %big column of all x values
Ycol = []; %big column lf all y values
Rcol = [];
m = 1; %increment

efold = 0.83; %efolding length (m)

rho1=rho; %record of original radius


%for m = 1:nodes; %make shells - shell number = nodes
    [X,Y]=pol2cart(zeta,r(m)); %Cartesian coordinates of each concentric shell
    Xcol = [Xcol;X];
    Ycol = [Ycol;Y];
%end

for m=1:spokes; % Record of the radius at each point.
    Rcol = [Rcol;r];
end
Rcol = Rcol(:); %Rcol is same length as Xcol and Ycol

Lx = length(Xcol);
y_alt(1:Lx)=0; %MOD - makes it a 2-D disc

n = 1;
DataC = []; %Empty matrix into which all the concs for each step are stored
rotations = [];
time = [];
diam = [];
f=1;
outsurf = []; %matrix of the exposure of outer shell each time step
skin = []; %exposure each time step used to accumulate outsurf
cumage = [0];

stable = 1;
years = ttime/rolls; %time at each orientation
steps50mm = ceil(years/500); %ceil(eros_years/50); %number of iterations to do at each time step if amount eroded is > 50mm.

blobby=years/steps50mm;

rotate = zeros(1,steps50mm); %rotation vector if need to hold boulder several steps before rotating


for f = 1:rolls, %Start big loop - 1 loop per step / rolling event
    
    rotate(steps50mm) = 2*pi*rand(1); %make boulder rotate at end of sitting interval
    for stable = 1:steps50mm; %removes incremental shells while boulder is stable
   
    omega = rotate(stable); %random angle (rad) for boulder to roll in clockwise direction - will be zero until stable = steps50mm
    accum = [];
    
     i1 = find(Rcol<=rho);
    [accum1] = sphere_line3_Lal(Xcol(i1)./1000, y_alt(i1)./1000, Ycol(i1)./1000, rho./1000); %this function assumes meters

    accum1 = (accum1.*0.5252.*blobby); %conversion for normalization by flat surface (1 atom/g/yr), multiply by years of exposure
    accum(1:Lx)=NaN;
    accum(i1)=accum1;
    accum = accum';
    
    [DataC] = [DataC,accum]; %Builds matrix of conc at each point for each interval (Lx x (f x steps50mm))
      
    

    
    XY=[Xcol,Ycol]; %Matrix of X and Y coordinates
    RotM = [cos(omega)  -sin(omega) ; sin(omega)  cos(omega)]; %Rotation matrix (clockwise)

    XrYr = XY*RotM; %rotates the points by angle omega (radians)

    Xcol = XrYr(:,1); %rotated x and y individual columns
    Ycol = XrYr(:,2);
    
    cumage = [cumage;cumage(end)+blobby]; %Records the cumulative age at each step
    
    skin = DataC;%%(DataCstart:DataCend,1:end); %Picks out the values in DataC reflecting external shell (100 x f)
    
    skinsum=sum(skin,2);% (spokes x 1) - conc of the outer skin
    outsurf = [outsurf,skinsum]; %makes a matrix of skin concs at each rotation (spokes x f)
    skin = [];%empties skin for next iteration
    rotations = [rotations;omega]; %records rotation angle, 
    time = [time;years]; %records time of each step (cf. cumage)
    diam = [diam;rho]; %records diameter at each step
    

f;

    end %end stable erosion sequence
end %end big loop - ie, end of a rotation interval.



%     
ConcT = sum(DataC,2); %sum the concentration for each coordinate for all the exposure intervals (Lx x 1), and normalize by rayz

skinvar = std(outsurf)'; %variance and mean of the outer layer at each step
skinmean = mean(outsurf)';
skiniqr = iqr(outsurf)';
skinmax = max(outsurf)';
skinmin = min(outsurf)';
skinvarmean = (skinvar./skinmean);

DataC; % option on screen read out of conc data at each time step
age = sum(time); %total age of boulder at end of run
cumage = cumage(2:end);

concnorm = (skinmean*Er)/(efold*1000); %nondimensionalised concentration, C*
timenorm = (cumage*Er)/(efold*1000); %nondimensionalised time, T*
normrad=diam/rho1; %normalised radius

[shield] = [Xcol,Ycol,ConcT]; %resultant matrix
[stats_all] =[cumage,diam,skinmean,skinvar,skinvarmean,normrad,concnorm,timenorm,skinmax,skinmin,skiniqr]; %8 columns of data - this used in MC script

[stats]=[stats_all(rolls:rolls:end,:)]; %pulls out the data from the end of each sitting period, cf each shell shedding

toc

